@@ -12,7 +12,7 @@ class TextEditorWindow(Window):
 
     """Text editor window"""
 
-    OVERLAY_CURSORROW = 'cursor_row'  # Name of overlay style of theme
+    OVERLAY_CURSORROW = 'cursor-row'  # Name of overlay style of theme
 
     show_lineno = True
     splitter = None
@@ -321,6 +321,12 @@ class TextEditorWindow(Window):
             self._cwnd.move(len(rows), 0)
             self._cwnd.clrtobot()
 
+            if self.document.mode.SHOW_BLANK_LINE:
+                attr = theme.get_style('blank-line-header').cui_colorattr
+                for i in range(len(rows), h):
+                    self._cwnd.move(i, 0)
+                    self.add_str('~', attr)
+
         if kaa.app.focus:
             if self.document.mode.is_cursor_visible():
                 kaa.app.focus._cwnd.move(cury, curx)
