@@ -4,7 +4,7 @@ from kaa.filetype.default import defaultmode
 from gappedbuf import re as gre
 from kaa.highlight import Tokenizer, Token, Span, Keywords, EndSection, SingleToken
 from kaa.theme import Theme, Style
-from kaa.command import Commands, command, norec, norerun
+from kaa.command import Commands, commandid, norec, norerun
 from kaa.keyboard import *
 
 MarkdownThemes = {
@@ -215,7 +215,7 @@ class MarkdownMode(defaultmode.DefaultMode):
             yield header
             stack.append((level, header))
 
-    @command('toc.showlist')
+    @commandid('toc.showlist')
     @norec
     @norerun
     def show_toclist(self, wnd):
